# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mortar.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import hod_pb2 as hod__pb2
import mdal_pb2 as mdal__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='mortar.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x0cmortar.proto\x12\x05proto\x1a\thod.proto\x1a\nmdal.proto\x1a\x1cgoogle/api/annotations.proto\"l\n\x0eQualifyRequest\x12,\n\x0frequiredqueries\x18\x01 \x03(\x0b\x32\x13.proto.QueryRequest\x12,\n\x0foptionalqueries\x18\x02 \x03(\x0b\x32\x13.proto.QueryRequest\"/\n\x0fQualifyResponse\x12\r\n\x05\x65rror\x18\x01 \x01(\t\x12\r\n\x05sites\x18\x02 \x03(\t\"8\n\x0c\x46\x65tchRequest\x12(\n\x07request\x18\x01 \x01(\x0b\x32\x17.proto.DataQueryRequest\"J\n\rFetchResponse\x12\r\n\x05\x65rror\x18\x01 \x01(\t\x12*\n\x08response\x18\x02 \x01(\x0b\x32\x18.proto.DataQueryResponse2\xb4\x01\n\x06Mortar\x12W\n\x07Qualify\x12\x15.proto.QualifyRequest\x1a\x16.proto.QualifyResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1/mortar/qualify:\x01*\x12Q\n\x05\x46\x65tch\x12\x13.proto.FetchRequest\x1a\x14.proto.FetchResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1/mortar/qualify:\x01*b\x06proto3')
  ,
  dependencies=[hod__pb2.DESCRIPTOR,mdal__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_QUALIFYREQUEST = _descriptor.Descriptor(
  name='QualifyRequest',
  full_name='proto.QualifyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='requiredqueries', full_name='proto.QualifyRequest.requiredqueries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='optionalqueries', full_name='proto.QualifyRequest.optionalqueries', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=76,
  serialized_end=184,
)


_QUALIFYRESPONSE = _descriptor.Descriptor(
  name='QualifyResponse',
  full_name='proto.QualifyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='proto.QualifyResponse.error', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sites', full_name='proto.QualifyResponse.sites', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=186,
  serialized_end=233,
)


_FETCHREQUEST = _descriptor.Descriptor(
  name='FetchRequest',
  full_name='proto.FetchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.FetchRequest.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=235,
  serialized_end=291,
)


_FETCHRESPONSE = _descriptor.Descriptor(
  name='FetchResponse',
  full_name='proto.FetchResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='proto.FetchResponse.error', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.FetchResponse.response', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=293,
  serialized_end=367,
)

_QUALIFYREQUEST.fields_by_name['requiredqueries'].message_type = hod__pb2._QUERYREQUEST
_QUALIFYREQUEST.fields_by_name['optionalqueries'].message_type = hod__pb2._QUERYREQUEST
_FETCHREQUEST.fields_by_name['request'].message_type = mdal__pb2._DATAQUERYREQUEST
_FETCHRESPONSE.fields_by_name['response'].message_type = mdal__pb2._DATAQUERYRESPONSE
DESCRIPTOR.message_types_by_name['QualifyRequest'] = _QUALIFYREQUEST
DESCRIPTOR.message_types_by_name['QualifyResponse'] = _QUALIFYRESPONSE
DESCRIPTOR.message_types_by_name['FetchRequest'] = _FETCHREQUEST
DESCRIPTOR.message_types_by_name['FetchResponse'] = _FETCHRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

QualifyRequest = _reflection.GeneratedProtocolMessageType('QualifyRequest', (_message.Message,), dict(
  DESCRIPTOR = _QUALIFYREQUEST,
  __module__ = 'mortar_pb2'
  # @@protoc_insertion_point(class_scope:proto.QualifyRequest)
  ))
_sym_db.RegisterMessage(QualifyRequest)

QualifyResponse = _reflection.GeneratedProtocolMessageType('QualifyResponse', (_message.Message,), dict(
  DESCRIPTOR = _QUALIFYRESPONSE,
  __module__ = 'mortar_pb2'
  # @@protoc_insertion_point(class_scope:proto.QualifyResponse)
  ))
_sym_db.RegisterMessage(QualifyResponse)

FetchRequest = _reflection.GeneratedProtocolMessageType('FetchRequest', (_message.Message,), dict(
  DESCRIPTOR = _FETCHREQUEST,
  __module__ = 'mortar_pb2'
  # @@protoc_insertion_point(class_scope:proto.FetchRequest)
  ))
_sym_db.RegisterMessage(FetchRequest)

FetchResponse = _reflection.GeneratedProtocolMessageType('FetchResponse', (_message.Message,), dict(
  DESCRIPTOR = _FETCHRESPONSE,
  __module__ = 'mortar_pb2'
  # @@protoc_insertion_point(class_scope:proto.FetchResponse)
  ))
_sym_db.RegisterMessage(FetchResponse)



_MORTAR = _descriptor.ServiceDescriptor(
  name='Mortar',
  full_name='proto.Mortar',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=370,
  serialized_end=550,
  methods=[
  _descriptor.MethodDescriptor(
    name='Qualify',
    full_name='proto.Mortar.Qualify',
    index=0,
    containing_service=None,
    input_type=_QUALIFYREQUEST,
    output_type=_QUALIFYRESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\027\"\022/v1/mortar/qualify:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='Fetch',
    full_name='proto.Mortar.Fetch',
    index=1,
    containing_service=None,
    input_type=_FETCHREQUEST,
    output_type=_FETCHRESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\027\"\022/v1/mortar/qualify:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_MORTAR)

DESCRIPTOR.services_by_name['Mortar'] = _MORTAR

# @@protoc_insertion_point(module_scope)
